An example dataset to use with the diversity-based assignment model. It is used to demonstrate the use of a custom dissimilarity matrix.
An example dataset to use with the diversity-based assignment model. It is used to demonstrate the use of a custom dissimilarity matrix.