Creates one row per student and one column per course-role pair, with units allocated by the solver.
Arguments
- model_result
Result object from
ompr::solve_model()for a PhD or multi-role workload model.- student_df
A data frame that contains student name information. Every row is a unique student.
- course_codes
Character vector of course codes in the same order as preference-matrix columns and
d_matrows.- name_col
Student name column name in
student_df.