powered by
An example dataset to use with the diversity-based assignment model. It is used to demonstrate the use of a custom dissimilarity matrix.
dba_gc_ex003
A matrix with 4 rows and 4 columns
id: the student id of each students, simply the integers 1 to 4.
self_groups: The self-formed groups
year, major: demographics used in computing dissimilarities