Learn R Programming

grouper (version 0.5.0)

dba_gc_ex004: DBA Group Composition Data Example 004

Description

An example dataset to use with the diversity-based assignment model. It is used to demonstrate the use of a vectors to indicate individual group size constraints for specific topics.

Usage

dba_gc_ex004

Arguments

Format

dba_gc_ex004

A matrix with 5 rows and 4 columns

  • id: the student id of each students, simply the integers 1 to 4.

  • self_groups: The self-formed groups

  • python: Python skill level - 1 is lowest, 3 is highest.