An example dataset to use with the diversity-based assignment model. It is used to demonstrate the use of a vectors to indicate individual group size constraints for specific topics.
dba_gc_ex004dba_gc_ex004
A matrix with 5 rows and 4 columns
id: the student id of each students, simply the integers 1 to 4.
self_groups: The self-formed groups
python: Python skill level - 1 is lowest, 3 is highest.