Learn R Programming

grouper (version 0.5.0)

extract_params_yaml: Extract parameters from a YAML file

Description

The remaining parameters for the models are retrieved from a YAML file, so as not to clutter the argument list for extract_student_info().

Usage

extract_params_yaml(fname, assignment = c("diversity", "preference"))

Value

For the diversity+skill-based assignment, this function returns a list containing:

  • n_topics: the number of topics

  • R: the optimally desired number of repetitions per topic

  • nmin: the minimum number of students per topic,

  • nmax: the maximum number of students per topic,

  • rmin: the minimum number of repetitions per topic,

  • rmax: the maximum number of repetitions per topic.

For the preference-based assignment, this function returns a list containing:

  • n_topics: the number of topics

  • R: the optimally desired number of repetitions per topic

  • nmin: the minimum number of students per topic,

  • nmax: the maximum number of students per topic,

  • rmin: the minimum number of repetitions per topic,

  • rmax: the maximum number of repetitions per topic.

Arguments

fname

A YAML file containing the remaining parameters.

assignment

Character string indicating the type of model that this dataset is for. The argument is either 'preference' or 'diversity'. Partial matching is fine.